@@ -178,7 +178,7 @@ uint ScreenCastPortal::Start(const QDBusObjectPath &handle,
                     for (int i = 0, c = model.rowCount(); i < c; ++i) {
                         const QModelIndex index = model.index(i, 0);
 
-                        if (model.data(index, KWayland::Client::PlasmaWindowModel::Uuid) == windowUuid) {
+                        if (model.data(index, KWayland::Client::PlasmaWindowModel::Uuid).toString() == windowUuid) {
                             selectedWindows << model.itemData(index);
                         }
                     }
@@ -272,8 +272,10 @@ uint ScreenCastPortal::Start(const QDBusObjectPath &handle,
         if (inhibitionsEnabled()) {
             new NotificationInhibition(app_id, i18nc("Do not disturb mode is enabled because...", "Screen sharing in progress"), session);
         }
+        qCDebug(XdgDesktopPortalKdeScreenCast) << "Screencast started successfully";
         return 0;
     }
 
+    qCWarning(XdgDesktopPortalKdeScreenCast) << "Aborting screencast";
     return 1;
 }
